==> mgb-0.6.2.tar.gz: email.php <==
<?php
	
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2007 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

        You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

        // ================ //
	// email.php - 1.1  //
	// ================ //
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //
	
	// show all errors
	error_reporting(E_ALL & ~E_NOTICE);
	
	header("Cache-Control: no-cache, must-revalidate"); // HTTP/1.1
	header("Expires: Mon, 26 Jul 1997 05:00:00 GMT"); // Datum in der Vergangenheit
	
	// check if MGB has been already installed
	if (file_exists("config.inc.php"))
		{		
		require ("config.inc.php");
		if(!isset($mgb_installation_complete))
			{
			echo "It seems as if you haven't installed the MGB yet. You can do that <a href=\"install/install.php\">here</a>.";
			die();
			}
		}
	else
		{
		echo "The config file could not be found. If you haven't installed the MGB yet, you can do that <a href=\"install/install.php\">here</a>.";		
		die();
		}

        // load config, settings, language files and necessary templates
        require ("config.inc.php");
	require ("functions.inc.php");
	require ("load_settings.inc.php");
	require ("language/".$settings['language_path']."/lang_main.php");
	require ("language/".$settings['language_path']."/settings.php");
	require ("load_templates.inc.php");	
	
	// load user data
	if ($_GET['id'] == "denied")
		{
		$errorcode = 8;
		$_POST['sent'] = 1;
		}
	elseif ($_GET['id'] != "admin")
		{		
		$sql = "SELECT name, email, user_show_email FROM ".$db['prefix']."entries WHERE id=".secure_value($_GET['id']);
		$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(email.php, Line 64) Error: ".mysql_error());
         	@mysql_select_db($db['dbname'], $link) or die ("(email.php, Line 65) Error: ".mysql_error());
		$result = @mysql_query($sql, $link) or die ("(email.php, Line 66) Error: ".mysql_error());

         	$sendemail = @mysql_fetch_array($result);
		
		$sendemail_name = $sendemail['name'];
		$sendemail_email = $sendemail['email'];
		$sendemail_user_show_email = $sendemail['user_show_email'];
		
		if ($sendemail_user_show_email == 0) { $errorcode = 8; $_POST['sent'] = 1; }
		}	
	else
		{
		$sendemail_email = $settings['admin_email'];
		$sendemail_name = $settings['admin_name'];
		}

        if (isset($_POST['sent']) AND $_POST['sent'] == 1)
		{
                // delete html, php code and white spaces
                
                if(!isset($_POST['user_sendcopytome'])) { $_POST['user_sendcopytome'] = 0; }
                if(!isset($_POST['name'])) { $_POST['name'] = NULL; }
                if(!isset($_POST['email'])) { $_POST['email'] = NULL; }
                if(!isset($_POST['message'])) { $_POST['message'] = NULL; }
                
	        $_POST['name'] = cleanstr($_POST['name']);
		$_POST['email'] = cleanstr($_POST['email']);
		$_POST['message'] = cleanstr($_POST['message']);
		$_POST['user_sendcopytome'] = cleanstr($_POST['user_sendcopytome']);

		// form was sent
		
		if (!isset($errorcode) OR $errorcode != 8)
			{
			// check if captcha is correct
			if ($settings['captcha'] == 1)
				{
				$sql = "SELECT `code` FROM ".$db['prefix']."captcha";
				$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(email.php, Line 104) Error: ".mysql_error());
				@mysql_select_db($db['dbname'], $link) or die ("(email.php, Line 105) Error: ".mysql_error());
				$result = @mysql_query($sql, $link) or die ("(email.php, Line 106) Error: ".mysql_error());

				$saved_code = @mysql_fetch_array($result);
				$captcha_code = $saved_code['code'];

				if ($captcha_code != $_POST['captcha']) { $errorcode = 7; }
				}

			// check email			
			if (!check_mail($_POST['email'])) { $errorcode = 4; }

			// check necessary fields
			if (!$_POST['message']) { $errorcode = 1; }
			if (!$_POST['email']) { $errorcode = 2; }
			if (!$_POST['name']) { $errorcode = 3; }

			if (!isset($errorcode))
				{                        
				// delete bbcode
				$_POST['name'] = bbcode_delete($_POST['name']);
				$_POST['message'] = bbcode_delete($_POST['message']);

				$_POST['message'] = nl2br($_POST['message']);
				$t1 = chr(10);
				$t2 = chr(13);
				$_POST['message'] = str_replace($t1,'', $_POST['message']);
				$_POST['message'] = str_replace($t2,'', $_POST['message']);
				
				$name = $_POST['name'];
				$email = $_POST['email'];
				$message = $_POST['message'];
				$url_to_gb = "http://".$settings['h_domain'].$settings['gb_path']."index.php";
					
				$date = date("d"."/"."m"."/"."Y");
				$time = date("H".":"."i");				
        		
				$mail_header = "content-type: text/plain; charset=".$charset."\n";
				$mail_header .= "from: ".$_POST['email']; 
				
				if (mail($sendemail_email,
					format_mail(repl_uml($lang['email_caption'], $charset), $name, $date, $time, xhtmlbr2nl($message), $settings['h_domain'], $url_to_gb, "", "", "", "", "", ""),
					format_mail(repl_uml($settings['sendmail_contactmail_text'], $charset), $name, $date, $time, xhtmlbr2nl($message), $settings['h_domain'], $url_to_gb, "", "", "", "", "", ""),
					$mail_header) == TRUE)
					{
					$sendemail_successfull = 1;
					
					if ($_POST['user_sendcopytome'] == 1)
						{
						mail($email,
						format_mail(repl_uml($lang['email_caption'], $charset), $name, $date, $time, xhtmlbr2nl($message), $settings['h_domain'], $url_to_gb, "", "", "", "", "", ""),
						format_mail(repl_uml($settings['sendmail_contactmail_text'], $charset), $name, $date, $time, xhtmlbr2nl($message), $settings['h_domain'], $url_to_gb, "", "", "", "", "", ""),
						$mail_header);
						}
					
					// refresh site
					$refresh = "<meta http-equiv=\"refresh\" content=\"3; URL=index.php\">";
					}
				else
					{
					unset($sendemail_successfull);
					$errorcode = 9;
					$refresh = NULL;
					}			
				}
			else
				{
				if ($errorcode == 1) { $errormessage = $lang['errormessage1']; }
				if ($errorcode == 2) { $errormessage = $lang['errormessage2']; }
				if ($errorcode == 3) { $errormessage = $lang['errormessage3']; }
				if ($errorcode == 4) { $errormessage = $_POST['email']."&nbsp;".$lang['errormessage4']; }
				if ($errorcode == 7) { $errormessage = $lang['errormessage7']; }
				if ($errorcode == 8) { $errormessage = $lang['errormessage8']; }				

				// do not refresh site
				$refresh = NULL;

				// generate new captchacode if activated
				if ($settings['captcha'] == 1)
					{
					generate_captcha();
					}
				}
			}
		else
			{
			// user don't wants to receive emails over guestbook
			$errormessage = $lang['errormessage8'];
			$refresh = NULL;			
			$sendemail_name = "-";
			
			// generate new captchacode if activated
			if ($settings['captcha'] == 1)
				{
				generate_captcha();
				}
			}
		}
	else
		{
                // form was not sent
		// do not refresh site
		$refresh = NULL;		
		}

	// Generate Page

	// fill header template with content
	$page_header = $content_header;
	
	// check if "install" directory has been deleted
	if (file_exists("install"))
		{
		$page_header = preg_replace("/\{INSTALL_DIRECTORY_EXISTS\}/", "<div style=\"background-color: white; padding: 3px; border: 2px solid black; width: 500px;\"><span style=\"color: red; font-size: 12px; font-weight: bold;\">".$lang['install_directory_exists']."</span></div>", $page_header);
		}
	else
		{
		$page_header = preg_replace("/\{INSTALL_DIRECTORY_EXISTS\}/", "", $page_header);
		}
		
	$page_header = preg_replace("/\{H_LANGUAGE_SHORT\}/", $language_short, $page_header);
	$page_header = preg_replace("/\{H_DOMAIN\}/", $settings['h_domain'], $page_header);
	$page_header = preg_replace("/\{H_AUTHOR\}/", $settings['h_author'], $page_header);
	$page_header = preg_replace("/\{H_KEYWORDS\}/", $settings['h_keywords'], $page_header);
	$page_header = preg_replace("/\{H_DESCRIPTION\}/", $settings['h_description'], $page_header);
	$page_header = preg_replace("/\{H_CHARSET\}/", $charset, $page_header);
	$page_header = preg_replace("/\{REFRESH\}/", $refresh, $page_header);

	if(!isset($errorcode))
		{
		$content_errormessage = NULL;
		}
	
	// generate captcha image
	if($settings['captcha'] == 1)
		{
		generate_captcha();
		$captcha = "<img src=\"captcha.php\" class=\"captcha\" title=\"".$lang['security_code']."\" alt=\"".$lang['security_code']."\">";
		$captcha = preg_replace("/\{CAPTCHA_IMG\}/", $captcha, $content_captcha);
		}
	else
		{
		$captcha = NULL;
		}

        // footer
	$page_footer = $content_footer;

         // entry was not successfull or it is the first time the site is loaded
	if(!isset($sendemail_successfull))
		{
                // get data from template
		$page_email_body = $content_email_body;
		
		if(isset($errorcode) AND $errorcode == 9) { $errormessage = $lang['errormessage9']; }
		
		// generate captchacode if activated
		if($settings['captcha'] == 1)
			{
         		generate_captcha();
			}

		// fill template with other templates if set
         	$page_email_body = preg_replace("/\{HEADER\}/", $page_header, $page_email_body);
		$page_email_body = preg_replace("/\{TEMPLATE_ERRORMESSAGE\}/", $content_errormessage, $page_email_body);
		$page_email_body = preg_replace("/\{TEMPLATE_CAPTCHA\}/", $captcha, $page_email_body);
		$page_email_body = preg_replace("/\{COPYRIGHT\}/", $content_copyright, $page_email_body);
        	$page_email_body = preg_replace("/\{FOOTER\}/", $page_footer, $page_email_body);
		$page_email_body = preg_replace("/\{MGB_VERSION\}/", $settings['version'], $page_email_body);
		$page_email_body = preg_replace("/\{COPYRIGHT_DATE\}/", date("Y"), $page_email_body);
		$page_email_body = preg_replace("/\{TEMPLATE_PATH\}/", "templates/".$settings['template_path'], $page_email_body);
		$page_email_body = preg_replace("/\{TEMPLATE_STYLE_PATH\}/", $settings['template_style_path'], $page_email_body);

         	// fill template with language and text strings
		if(!isset($errormessage)) { $errormessage = NULL; }
		$page_email_body = preg_replace("/\{ERRORMESSAGE\}/", $errormessage, $page_email_body);
		$page_email_body = preg_replace("/\{TITLE\}/", $settings['title'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_EMAIL_NAME\}/", $lang['name'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_EMAIL_EMAIL\}/", $lang['email'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_EMAIL_MESSAGE\}/", $lang['message'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_NECESSARY_FIELDS\}/", $lang['necessary_fields'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_EMAIL_SENT_TO\}/", $lang['email_sent_to'], $page_email_body);
		$page_email_body = preg_replace("/\{EMAIL_RECEIVER\}/", $sendemail_name, $page_email_body);
		$page_email_body = preg_replace("/\{LANG_USER_SENDCOPYTOME\}/", $lang['email_sendcopytome'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_CAPTCHA_WHAT_IS_THAT\}/", $lang['captcha_what_is_that'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_CAPTCHA_WIKIPEDIA\}/", $lang['captcha_wikipedia'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_CAPTCHA_TOOLTIP\}/", $lang['captcha_tooltip'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_SECURITY_CODE\}/", $lang['security_code'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_SEND\}/", $lang['email_send'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_BACK\}/", $lang['back'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_BACK_TO_MAINPAGE\}/", $lang['back_to_mainpage'], $page_email_body);

		// fill template with sent strings		
		if(!isset($_POST['sent']))
			{
			$_POST['name'] = "";			
			$_POST['email'] = "";			
			$_POST['message'] = "";
			}
			
		$page_email_body = preg_replace("/\{POST_NAME\}/", $_POST['name'], $page_email_body);
		$page_email_body = preg_replace("/\{POST_EMAIL\}/", $_POST['email'], $page_email_body);
		$page_email_body = preg_replace("/\{POST_MESSAGE\}/", $_POST['message'], $page_email_body);

		// fill template with general data
		$page_email_body = preg_replace("/\{FORM_ACTION\}/", "email.php?id=".cleanstr($_GET['id']), $page_email_body);
		}
	else
		{
                 // entry was successfull, load other template
		$page_email_body = $content_email_body_success;

        	// fill template with other templates
         	$page_email_body = preg_replace("/\{HEADER\}/", $page_header, $page_email_body);
		$page_email_body = preg_replace("/\{TITLE\}/", $settings['title'], $page_email_body);
                $page_email_body = preg_replace("/\{LANG_EMAIL_SUCCESS\}/", $lang['email_success'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_FORWARDING\}/", $lang['forwarding'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_BACK\}/", $lang['back'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_BACK_TO_MAINPAGE\}/", $lang['back_to_mainpage'], $page_email_body);
                $page_email_body = preg_replace("/\{COPYRIGHT\}/", $content_copyright, $page_email_body);
        	$page_email_body = preg_replace("/\{FOOTER\}/", $page_footer, $page_email_body);
		$page_email_body = preg_replace("/\{MGB_VERSION\}/", $settings['version'], $page_email_body);
		$page_email_body = preg_replace("/\{COPYRIGHT_DATE\}/", date("Y"), $page_email_body);
		$page_email_body = preg_replace("/\{TEMPLATE_PATH\}/", "templates/".$settings['template_path'], $page_email_body);
		$page_email_body = preg_replace("/\{TEMPLATE_STYLE_PATH\}/", $settings['template_style_path'], $page_email_body);
		}

	echo $page_email_body;
?>

==> mgb-0.6.3.tar.gz: email.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2007 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ================ //
	// email.php - 1.1  //
	// ================ //
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	// show all errors
	error_reporting(E_ALL & ~E_NOTICE);

	header("Cache-Control: no-cache, must-revalidate"); // HTTP/1.1
	header("Expires: Mon, 26 Jul 1997 05:00:00 GMT"); // Datum in der Vergangenheit

	// check if MGB has been already installed
	if (file_exists("config.inc.php"))
		{
		require ("config.inc.php");
		if(!isset($mgb_installation_complete))
			{
			echo "It seems as if you haven't installed the MGB yet. You can do that <a href=\"install/install.php\">here</a>.";
			die();
			}
		}
	else
		{
		echo "The config file could not be found. If you haven't installed the MGB yet, you can do that <a href=\"install/install.php\">here</a>.";
		die();
		}

	// load config, settings, language files and necessary templates
	require ("config.inc.php");
	require ("functions.inc.php");
	require ("load_settings.inc.php");
	require ("language/".$settings['language_path']."/lang_main.php");
	require ("language/".$settings['language_path']."/settings.php");
	require ("load_templates.inc.php");
	
	// load user data
	if ($_GET['id'] == "denied")
		{
		$errorcode = 8;
		$_POST['sent'] = 1;
		}
	elseif ($_GET['id'] != "admin")
		{
		$sql = "SELECT name, email, user_show_email FROM ".$db['prefix']."entries WHERE id=".secure_value($_GET['id']);
		$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(email.php) Error, line 66: ".mysql_error());
		@mysql_select_db($db['dbname'], $link) or die ("(email.php) Error, line 67 ".mysql_error());
		$result = @mysql_query($sql, $link) or die ("(email.php) Error, line 68: ".mysql_error());

		$sendemail = @mysql_fetch_array($result);
		
		$sendemail_name = $sendemail['name'];
		$sendemail_email = $sendemail['email'];
		$sendemail_user_show_email = $sendemail['user_show_email'];
		
		if ($sendemail_user_show_email == 0) { $errorcode = 8; $_POST['sent'] = 1; }
		}
	else
		{
		$sendemail_email = $settings['admin_email'];
		$sendemail_name = $settings['admin_name'];
		}

	if (isset($_POST['sent']) AND $_POST['sent'] == 1)
		{
		// delete html, php code and white spaces
		
		if(!isset($_POST['user_sendcopytome'])) { $_POST['user_sendcopytome'] = 0; }
		if(!isset($_POST['name'])) { $_POST['name'] = NULL; }
		if(!isset($_POST['email'])) { $_POST['email'] = NULL; }
		if(!isset($_POST['message'])) { $_POST['message'] = NULL; }
		
		$_POST['name'] = cleanstr($_POST['name']);
		$_POST['email'] = cleanstr($_POST['email']);
		$_POST['message'] = cleanstr($_POST['message']);
		$_POST['user_sendcopytome'] = cleanstr($_POST['user_sendcopytome']);

		// form was sent
		
		if (!isset($errorcode) OR $errorcode != 8)
			{
			// check if captcha is correct
			if ($settings['captcha'] == 1)
				{
				$sql = "SELECT `code` FROM ".$db['prefix']."captcha";
				$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(email.php) Error, line 106: ".mysql_error());
				@mysql_select_db($db['dbname'], $link) or die ("(email.php) Error, line 107: ".mysql_error());
				$result = @mysql_query($sql, $link) or die ("(email.php) Error, line 108: ".mysql_error());

				$saved_code = @mysql_fetch_array($result);
				$captcha_code = $saved_code['code'];

				if ($captcha_code != $_POST['captcha']) { $errorcode = 7; }
				}

			// check email
			if (!check_mail($_POST['email'])) { $errorcode = 4; }

			// check necessary fields
			if (!$_POST['message']) { $errorcode = 1; }
			if (!$_POST['email']) { $errorcode = 2; }
			if (!$_POST['name']) { $errorcode = 3; }

			if (!isset($errorcode))
				{
				// delete bbcode
				$_POST['name'] = bbcode_delete($_POST['name']);
				$_POST['message'] = bbcode_delete($_POST['message']);

				$_POST['message'] = nl2br($_POST['message']);
				$t1 = chr(10);
				$t2 = chr(13);
				$_POST['message'] = str_replace($t1,'', $_POST['message']);
				$_POST['message'] = str_replace($t2,'', $_POST['message']);
				
				$name = $_POST['name'];
				$email = $_POST['email'];
				$message = $_POST['message'];
				$url_to_gb = "http://".$settings['h_domain'].$settings['gb_path']."index.php";

				$date = date("d"."/"."m"."/"."Y");
				$time = date("H".":"."i");

				$mail_header = "content-type: text/plain; charset=".$charset."\n";
				$mail_header .= "from: ".$_POST['email']; 

				if (mail($sendemail_email,
					format_mail(repl_uml($lang['email_caption'], $charset), $name, $date, $time, xhtmlbr2nl($message), $settings['h_domain'], $url_to_gb, "", "", "", "", "", ""),
					format_mail(repl_uml($settings['sendmail_contactmail_text'], $charset), $name, $date, $time, xhtmlbr2nl($message), $settings['h_domain'], $url_to_gb, "", "", "", "", "", ""),
					$mail_header) == TRUE)
					{
					$sendemail_successfull = 1;
					
					if ($_POST['user_sendcopytome'] == 1)
						{
						mail($email,
						format_mail(repl_uml($lang['email_caption'], $charset), $name, $date, $time, xhtmlbr2nl($message), $settings['h_domain'], $url_to_gb, "", "", "", "", "", ""),
						format_mail(repl_uml($settings['sendmail_contactmail_text'], $charset), $name, $date, $time, xhtmlbr2nl($message), $settings['h_domain'], $url_to_gb, "", "", "", "", "", ""),
						$mail_header);
						}

					// refresh site
					$refresh = "<meta http-equiv=\"refresh\" content=\"3; URL=index.php\">";
					}
				else
					{
					unset($sendemail_successfull);
					$errorcode = 9;
					$refresh = NULL;
					}
				}
			else
				{
				if ($errorcode == 1) { $errormessage = $lang['errormessage1']; }
				if ($errorcode == 2) { $errormessage = $lang['errormessage2']; }
				if ($errorcode == 3) { $errormessage = $lang['errormessage3']; }
				if ($errorcode == 4) { $errormessage = $_POST['email']."&nbsp;".$lang['errormessage4']; }
				if ($errorcode == 7) { $errormessage = $lang['errormessage7']; }
				if ($errorcode == 8) { $errormessage = $lang['errormessage8']; }

				// do not refresh site
				$refresh = NULL;

				// generate new captchacode if activated
				if ($settings['captcha'] == 1)
					{
					generate_captcha();
					}
				}
			}
		else
			{
			// user don't wants to receive emails over guestbook
			$errormessage = $lang['errormessage8'];
			$refresh = NULL;
			$sendemail_name = "-";

			// generate new captchacode if activated
			if ($settings['captcha'] == 1)
				{
				generate_captcha();
				}
			}
		}
	else
		{
		// form was not sent
		// do not refresh site
		$refresh = NULL;
		}

	// Generate Page

	// fill header template with content
	$page_header = $content_header;
	
	// check if "install" directory has been deleted
	if (file_exists("install"))
		{
		$page_header = preg_replace("/\{INSTALL_DIRECTORY_EXISTS\}/", "<div style=\"background-color: white; padding: 3px; border: 2px solid black; width: 500px;\"><span style=\"color: red; font-size: 12px; font-weight: bold;\">".$lang['install_directory_exists']."</span></div>", $page_header);
		}
	else
		{
		$page_header = preg_replace("/\{INSTALL_DIRECTORY_EXISTS\}/", "", $page_header);
		}
		
	$page_header = preg_replace("/\{H_LANGUAGE_SHORT\}/", $language_short, $page_header);
	$page_header = preg_replace("/\{H_DOMAIN\}/", $settings['h_domain'], $page_header);
	$page_header = preg_replace("/\{H_AUTHOR\}/", $settings['h_author'], $page_header);
	$page_header = preg_replace("/\{H_KEYWORDS\}/", $settings['h_keywords'], $page_header);
	$page_header = preg_replace("/\{H_DESCRIPTION\}/", $settings['h_description'], $page_header);
	$page_header = preg_replace("/\{H_CHARSET\}/", $charset, $page_header);
	$page_header = preg_replace("/\{REFRESH\}/", $refresh, $page_header);

	if(!isset($errorcode))
		{
		$content_errormessage = NULL;
		}

	// generate captcha image
	if($settings['captcha'] == 1)
		{
		generate_captcha();
		$captcha = "<img src=\"captcha.php\" class=\"captcha\" title=\"".$lang['security_code']."\" alt=\"".$lang['security_code']."\">";
		$captcha = preg_replace("/\{CAPTCHA_IMG\}/", $captcha, $content_captcha);
		}
	else
		{
		$captcha = NULL;
		}

	// footer
	$page_footer = $content_footer;

	 // entry was not successfull or it is the first time the site is loaded
	if(!isset($sendemail_successfull))
		{
		// get data from template
		$page_email_body = $content_email_body;

		// eMail could not be sent, show errormessage
		if(isset($errorcode) AND $errorcode == 9) { $errormessage = $lang['errormessage9']; }

		// generate captchacode if activated
		if($settings['captcha'] == 1)
			{
			generate_captcha();
			}

		// fill template with other templates if set
		$page_email_body = preg_replace("/\{HEADER\}/", $page_header, $page_email_body);
		$page_email_body = preg_replace("/\{TEMPLATE_ERRORMESSAGE\}/", $content_errormessage, $page_email_body);
		$page_email_body = preg_replace("/\{TEMPLATE_CAPTCHA\}/", $captcha, $page_email_body);
		$page_email_body = preg_replace("/\{COPYRIGHT\}/", $content_copyright, $page_email_body);
		$page_email_body = preg_replace("/\{FOOTER\}/", $page_footer, $page_email_body);
		$page_email_body = preg_replace("/\{MGB_VERSION\}/", $settings['version'], $page_email_body);
		$page_email_body = preg_replace("/\{COPYRIGHT_DATE\}/", date("Y"), $page_email_body);
		$page_email_body = preg_replace("/\{TEMPLATE_PATH\}/", "templates/".$settings['template_path'], $page_email_body);
		$page_email_body = preg_replace("/\{TEMPLATE_STYLE_PATH\}/", $settings['template_style_path'], $page_email_body);

		// fill template with language and text strings
		if(!isset($errormessage)) { $errormessage = NULL; }
		$page_email_body = preg_replace("/\{ERRORMESSAGE\}/", $errormessage, $page_email_body);
		$page_email_body = preg_replace("/\{TITLE\}/", $settings['title'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_EMAIL_NAME\}/", $lang['name'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_EMAIL_EMAIL\}/", $lang['email'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_EMAIL_MESSAGE\}/", $lang['message'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_NECESSARY_FIELDS\}/", $lang['necessary_fields'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_EMAIL_SENT_TO\}/", $lang['email_sent_to'], $page_email_body);
		$page_email_body = preg_replace("/\{EMAIL_RECEIVER\}/", $sendemail_name, $page_email_body);
		$page_email_body = preg_replace("/\{LANG_USER_SENDCOPYTOME\}/", $lang['email_sendcopytome'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_CAPTCHA_WHAT_IS_THAT\}/", $lang['captcha_what_is_that'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_CAPTCHA_WIKIPEDIA\}/", $lang['captcha_wikipedia'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_CAPTCHA_TOOLTIP\}/", $lang['captcha_tooltip'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_SECURITY_CODE\}/", $lang['security_code'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_SEND\}/", $lang['email_send'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_BACK\}/", $lang['back'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_BACK_TO_MAINPAGE\}/", $lang['back_to_mainpage'], $page_email_body);

		// fill template with sent strings
		if(!isset($_POST['sent']))
			{
			$_POST['name'] = "";
			$_POST['email'] = "";
			$_POST['message'] = "";
			}
			
		$page_email_body = preg_replace("/\{POST_NAME\}/", $_POST['name'], $page_email_body);
		$page_email_body = preg_replace("/\{POST_EMAIL\}/", $_POST['email'], $page_email_body);
		$page_email_body = preg_replace("/\{POST_MESSAGE\}/", $_POST['message'], $page_email_body);

		// fill template with general data
		$page_email_body = preg_replace("/\{FORM_ACTION\}/", "email.php?id=".cleanstr($_GET['id']), $page_email_body);
		}
	else
		{
		 // entry was successfull, load other template
		$page_email_body = $content_email_body_success;

		// fill template with other templates
		$page_email_body = preg_replace("/\{HEADER\}/", $page_header, $page_email_body);
		$page_email_body = preg_replace("/\{TITLE\}/", $settings['title'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_EMAIL_SUCCESS\}/", $lang['email_success'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_FORWARDING\}/", $lang['forwarding'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_BACK\}/", $lang['back'], $page_email_body);
		$page_email_body = preg_replace("/\{LANG_BACK_TO_MAINPAGE\}/", $lang['back_to_mainpage'], $page_email_body);
		$page_email_body = preg_replace("/\{COPYRIGHT\}/", $content_copyright, $page_email_body);
		$page_email_body = preg_replace("/\{FOOTER\}/", $page_footer, $page_email_body);
		$page_email_body = preg_replace("/\{MGB_VERSION\}/", $settings['version'], $page_email_body);
		$page_email_body = preg_replace("/\{COPYRIGHT_DATE\}/", date("Y"), $page_email_body);
		$page_email_body = preg_replace("/\{TEMPLATE_PATH\}/", "templates/".$settings['template_path'], $page_email_body);
		$page_email_body = preg_replace("/\{TEMPLATE_STYLE_PATH\}/", $settings['template_style_path'], $page_email_body);
		}

	echo $page_email_body;
?>
